<?php

declare(strict_types=1);

namespace Dedi\SyliusCmsPlugin\Form\Type\UiElement;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\DateType;
use Symfony\Component\Form\Extension\Core\Type\FileType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints as Assert;

class ArticleType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('title', TextType::class, [
                'label' => 'dedi_cms.ui_element.elements.title',
            ])
            ->add('htmlTag', ChoiceType::class, [
                'label' => 'dedi_cms.ui_element.elements.html_tag',
                'choices' => [
                    'H1' => 'h1',
                    'H2' => 'h2',
                    'H3' => 'h3',
                    'H4' => 'h4',
                    'H5' => 'h5',
                    'H6' => 'h6',
                    'P' => 'p',
                ],
                'empty_data' => 'h2',
            ])
            ->add('place', TextType::class, [
                'label' => 'dedi_cms.ui_element.article.field.place',
                'required' => false,
            ])
            ->add('creation', DateType::class, [
                'label' => 'dedi_cms.ui_element.article.field.date',
                'widget' => 'single_text',
                'input' => 'string',
                'required' => false,
            ])
            ->add('link', TextType::class, [
                'label' => 'monsieurbiz_richeditor_plugin.ui_element.monsieurbiz.image.field.link',
                'constraints' => [
                    new Assert\Url([]),
                ],
            ])
            ->add('image', FileType::class, [
                'label' => 'monsieurbiz_richeditor_plugin.ui_element.monsieurbiz.image.field.image',
                'data_class' => null,
                'required' => true,
                'attr' => ['data-image' => 'true'], // To be able to manage display in form
            ])
            ->add('alt', TextType::class, [
                'required' => false,
                'label' => 'monsieurbiz_richeditor_plugin.ui_element.monsieurbiz.image.field.alt',
            ])
        ;
    }
}
