<?php

declare(strict_types=1);

namespace Dedi\SyliusCmsPlugin\Form\Type\UiElement;

use Dedi\SyliusCmsPlugin\Form\Type\UiElement\Base\LinkType;
use Dedi\SyliusCmsPlugin\Form\Type\UiElement\Base\MediaType;
use MonsieurBiz\SyliusRichEditorPlugin\Form\Type\WysiwygType;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\TextType as FormTextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Validator\Constraints as Assert;

class TextAndMediaType extends AbstractType
{
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('media', MediaType::class, [
                'label' => 'dedi_cms.ui_element.text_and_media.media',
                'embedded' => true,
            ])
            ->add('mediaBeforeText', CheckboxType::class, [
                'label' => 'dedi_cms.ui_element.text_and_media.is_media_before_text',
                'required' => false,
            ])
            ->add('title', FormTextType::class, [
                'label' => 'dedi_cms.ui_element.elements.title',
                'required' => false,
            ])
            ->add('htmlTag', ChoiceType::class, [
                'label' => 'dedi_cms.ui_element.elements.html_tag',
                'choices' => [
                    'H1' => 'h1',
                    'H2' => 'h2',
                    'H3' => 'h3',
                    'H4' => 'h4',
                    'H5' => 'h5',
                    'H6' => 'h6',
                    'P' => 'p',
                ],
                'empty_data' => 'h2',
            ])
            ->add('text', WysiwygType::class, [
                'required' => true,
                'label' => 'monsieurbiz_richeditor_plugin.ui_element.monsieurbiz.text.field.content',
                'constraints' => [
                    new Assert\NotBlank([]),
                ],
            ])
            ->add('link', LinkType::class, [
                'label' => 'dedi_cms.ui_element.text_and_image.link',
                'required' => false,
                'embedded' => true,
            ])
        ;
    }
}
